package Module::Install::PRIVATE;

use strict;
use warnings;
use Carp;
use English qw( -no_match_vars );

use base q{Module::Install::Base};
use File::Basename;
use feature q{switch};

sub exclude_docs {
    my $self = shift;
    return $self->{MI_PRIVATE_EXCLUDE_DOCS} = [@_];
}

sub install_docs {

    my $self = shift;

    # Unfortunately, touching PM turns off MakeMaker's autoscan.
    # So create a new MM object, get it to do the autoscan, grab
    # the PM files it found, and add the podfiles to it

    if ( not @_ ) {
        push @_, q{doc};
    }

    my $mm = ExtUtils::MakeMaker->new({
        NAME      => $self->name,
        PMLIBDIRS => [ @_, q{lib}, basename($self->name) ],
    });
    $mm->init_PM;

    my $args = $self->makemaker_args;
    my $libs = $args->{PM} ||= $mm->{PM}
        or croak q{MakeMaker didn't find any PM files?!};

    my $man1pods = $args->{MAN1PODS} ||= $mm->{MAN1PODS};
    my $man3pods = $args->{MAN3PODS} ||= $mm->{MAN3PODS};

    foreach my $dir ( @_ ) {
        if ( -d $dir ) {
          FILE:
            foreach my $file ( glob(qq{$dir/*.pod}) ) {
                foreach my $exclusion ( @{ $self->{MI_PRIVATE_EXCLUDE_DOCS} } ) {
                    next FILE if $file ~~ $exclusion;
                }
                ## no critic: RequireInterpolationOfMetachars
                my $filename  = basename($file);
                my ($docname) = ($filename =~ m{ (.*) [.] pod $}xms );
                $libs->{$file} = q{$(INST_LIBDIR)/} . basename($file);
                $man1pods->{$file} = q{blib/man1/} . $docname . q{.1};
                delete $man3pods->{$file};
            }
        }
        else {
            croak qq{Can't find docdir '$dir'};
        }
    }

    return;

}

1; # Magic true value required at end of module
__END__

=for :stopwords EFS smartmatch regex MakeMaker

=head1 NAME

Module::Install::PRIVATE - Private installer routines for EFS


=head1 SYNOPSIS

    exclude_docs qr/PRIV/;   # Don't install docs matching regex
    install_docs;            # install docs in 'doc/' directory

    install_docs 'podfiles'; # use 'podfiles/' directory instead


=head1 DESCRIPTION

These are the private installer routines used by EFS.  These should
NOT be included in the distribution directly.  They will be included
automatically by Module::Install.

=head1 INTERFACE

=head2 exclude_docs [$filter, ...]

Lets you exclude one or more docs from the installed docs.  $filter
can be anything a smartmatch (C<~~>) would match, for example a qr//
regex or a string.

Use this before using C<install_docs>.

=head2 install_docs [$dir, ...]

Tells MakeMaker to include files in a documentation directory along
with the files in I<lib/>.  By default, this is a directory called
C<doc>, but you can give whatever other name relative to the source
root you like.  You can give this multiple times to include different
directories.

=head1 AUTHOR

Trey Harris

=cut



# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
