package EFS::CLI::ForbiddenFileRule;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};
use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name        => { type => SCALAR },
        regex       => { type => SCALAR },
        description => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($ffrule) = $resultset->search({ name => $args{name} });

    if ( $ffrule ) {

        STDOUT->print( qq{Forbidden file rule $args{name} is already defined\n} );

        if ( $ffrule->description ne $args{description} ) {
            $ffrule->set_column( description => $args{description} );
            $ffrule->update;
            STDOUT->print( qq{Updated description of forbidden file rule $ffrule\n} );
        }

    } else {

        $ffrule = $resultset->create({
            name        => $args{name},
            regex       => $args{regex},
            description => $args{description},
        });

        STDOUT->print( qq{Defined forbidden file rule $args{name}\n} );

    }

    return $ffrule;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my $ffrule = $resultset->retrieve_bynames_assert( name => $args{name} );

    $ffrule->delete;

    STDOUT->print( qq{Undefined forbidden file rule $args{name}\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( not $args{name} ) {
        $class->display_objects( objects => [ $resultset->all ] );
        return 1;
    }

    my $ffrule = $resultset->retrieve_bynames_assert( name => $args{name} );

    $class->display_objects( objects => [ $ffrule ] );

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
        %EFS::CLI::History::validation_specs,
    });

    $args{ffrule} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
