package EFS::DBI::Result::Home;

use strict;
use warnings;
use English;

use feature q{switch};

use base q{EFS::DBI::Result};

use Date::Format;
use File::Basename qw(dirname basename);

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix Core/ );

__PACKAGE__->table( q{home} );

__PACKAGE__->add_columns(
    id        => { __PACKAGE__->get_id_column_attrs },
    name      => { efs_column_group => [qw( display )] },
    cell      => { efs_column_group => [qw( display )] },
    destroyed => { efs_column_group => [qw( display )] },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{home_seq} );

__PACKAGE__->belongs_to( cell => q{EFS::DBI::Result::Cell} );

__PACKAGE__->has_many( attrs => q{EFS::DBI::Result::HomeAttrs} );

sub display_columns {
    return qw(name cell);
}

sub object_id {
    my $self = shift;
    my $separator = shift || q{/};
    return join ( $separator,
                  substr($self->name,0,1),
                  substr($self->name,0,2),
                  $self->name );
}

sub get_path {
    my $self = shift;
    return join q{/}, q{/efs/home}, $self->object_id;
}

sub get_path_admin {
    my $self = shift;
    my $cell = shift || $self->cell;
    my $admin_path = $cell->admin_path( type => q{home} );
    return join q{/}, $admin_path, q{home}, $self->object_id;
}

sub get_path_destroyed {
    my $self = shift;
    my $path_admin = $self->get_path_admin;
    return join q{/}, dirname($path_admin), q{.destroyed}, basename($path_admin);
}

sub autopath {

    my $self = shift;

    my $cell = $self->cell;

    my $autopath = q{};

    given ( $cell->fstype ) {

        when ( q{afs} ) {
            $autopath = join(
                q{/},
                q{/afs},
                $cell->name,
                q{efs/home},
                $self->object_id,
            );
        }

        when ( q{nfs} ) {
            my ($fileshare) = $cell->fileshares({ filetype => q{home} }) or
                die qq{No home fileshares defined for $cell\n};
            my ($fileqtree) = $fileshare->fileqtrees({ name => q{efs_qtree} });
            $autopath = join(
                q{/},
                q{/.efsglobal},
                $fileshare->autoname,
                $fileqtree->name,
                $self->object_id,
            );
        }

    }

    return $autopath;

}

# XXX: Not sure about this one...
sub move_backout {

    my $self = shift;
    my %args = @_;

    EFS::CLI::Namespace->addentry(
        type     => q{home},
        realpath => $self->object_id,
        autopath => $self->autopath,
    );

    die(
        qq{Unable to complete move of home to $args{tocell}:\n},
        $args{message},
    );

    return;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
