package EFS::DBI::ResultSet::Fileserver;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {

    my $class = shift;
    my %data  = @_;

    return 1 unless exists $data{fileserver};

    my $parameter_rs = $class->get_resultset( q{Parameter} );

    my $root = $parameter_rs->configured( q{root_domain} );

    $data{fileserver} =~ m/\A [-\w\.]+ \z/msx || die(
        qq{Invalid fileserver name '$data{fileserver}'\n},
        q{Must consist solely of alphanumeric characters, },
        qq{underscores, dashes and/or dots\n}
    );

    return;
}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        cell => { type => SCALAR },
        name => { type => SCALAR },
    });

    my $cell_rs = EFS::DBI->get_resultset( q{Cell} );

    my $cell = $cell_rs->retrieve_bynames_assert( name => $args{cell} );

    my ($fileserver) = $self->search({
        cell => $cell->id,
        name => $args{name},
    });

    if ( not $fileserver ) {
        die qq{No such fileserver '$args{name}' in cell '$cell'\n};
    }

    return $fileserver;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
