package EFS::DBI::ResultSet::ReleaseAlias;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

{

    my %is_reserved = map { $_ => 1 }
        qw( prod beta qa test );

    sub assert_not_reserved {

        my $class = shift;
        my $word  = shift;

        if ( $is_reserved{$word} ) {
            die(
                q{Attempt to use word reserved for },
                qq{releasealias use only: $word\n}
            );
        }

        return 1;

    }

}

sub validate_data {

    my $class = shift;
    my %data  = @_;

    foreach my $type ( qw( releasealias target ) ) {
        if ( not exists $data{$type} ) {
            next;
        }
        $data{$type} =~ m/\A [-\w\.]+ \z/msx || die(
            qq{Invalid $type name '$data{$type}'\n},
            q{Must consist solely of alphanumeric characters, },
            qq{underscores, dashes and/or dots\n}
        );
    }

    return 1;

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        metaproj => { type => SCALAR },
        project  => { type => SCALAR },
        name     => { type => SCALAR },
        disabled => { type => BOOLEAN, optional => 1 },
    });

    my $project_rs = EFS::DBI->get_resultset( q{Project} );

    my $project = $project_rs->retrieve_bynames_assert(
        metaproj => $args{metaproj},
        name     => $args{project},
        disabled => $args{disabled},
    );

    my ($releasealias) = $self->search({
        project => $project->id,
        name    => $args{name},
    });

    if ( not $releasealias ) {
        die qq{No such releasealias '$project/$args{name}'\n};
    }

    if ( not $args{disabled} ) {
        $project->assert_not_disabled;
    }

    return $releasealias;

}

sub retrieve_bynames {

    my $self = shift;

    my (%args) = validate( @_, {
        metaproj => { type => SCALAR },
        project  => { type => SCALAR },
        name     => { type => SCALAR },
        disabled => { type => BOOLEAN, optional => 1 },
    });

    my $project_rs = EFS::DBI->get_resultset( q{Project} );

    my $project = $project_rs->retrieve_bynames(
        metaproj => $args{metaproj},
        name     => $args{project},
        disabled => $args{disabled},
    );

    if ( not $project ) {
        return;
    }

    my ($releasealias) = $self->search({
        project => $project->id,
        name    => $args{name},
    });

    return $releasealias;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
