package EFS::Diststate::Release;

use strict;
use warnings;
use English;

use Moose;
use Params::Validate qw( :all );
use List::MoreUtils qw( all any );

extends qw(EFS::Diststate);
use EFS::Diststate::Install;


has release => (
    is => 'rw',
);

has install_diststate => (
    is => 'rw',
    default => sub { {} },
);


sub BUILD {

    my ($self,@args) = @_;

    my (%args) = validate( @args, {
        release => {
            type => OBJECT,
            isa  => q{EFS::DBI::Result::Release}
        },
    });

    my $release = $self->release( $args{release} );

    my @installs = $release->installs;

    foreach my $install (@installs) {
        $self->install_diststate->{ $install->name } =
            EFS::Diststate::Install->new( {install => $install} );
    }

    return;
}

sub related_item { return shift->get_release }

# The only subitem diststates we're interested in
# are where there is a valid checktime.  Cases without
# checktimes (e.g., empty installs, never disted) or
# with invalid checktimes because of audit are skipped
sub subitem_diststates {
    my ( $self ) = @_;
    return grep { $_->get_checktime > 0 }
        values %{ $self->install_diststate };
}

sub releases_needing_update {

    my $self = shift;

    my (%args) = validate( @_, {
        cells => { type => ARRAYREF, optional => 1 },
    });

    if ( $self->needs_update(%args) ) {
        return $self;
    }
    else {
        return ();
    }

}

sub releases_updated {

    my $self = shift;

    my (%args) = validate( @_, {
        cells => { type => ARRAYREF, optional => 1 },
    });

    if ( $self->has_been_updated(%args) ) {
        return $self;
    }
    else {
        return ();
    }
}

sub _subitem_type { return q{install} }

# For a release diststate, the mpr list is just this release
sub mprs {
    return shift->get_release;
}


1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
