#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test::Config;

use blib;
use EFS;

my $config = EFS::Test::Config->new;

# Parameters

ok(
    EFS::CLI::Parameter->define(
        name  => q{root_domain},
        value => $config->get_value( q{Global}, q{root_domain} ),
    ),
    q{Defined root_domain parameter}
);

ok(
    EFS::CLI::Parameter->define(
        name  => q{disable_logfile_archive},
        value => 1,
    ),
    q{Defined disable_logfile_archive parameter}
);

ok(
    EFS::CLI::Parameter->define(
        name  => q{database_type},
        value => q{test},
    ),
    q{Defined database_type parameter}
);

ok(
    EFS::CLI::Parameter->define(
        name  => q{ssl_root_certificate_lifetime},
        value => 365,
    ),
    q{Defined ssl_root_certificate_lifetime parameter}
);

ok(
    EFS::CLI::Parameter->define(
        name  => q{ssl_server_certificate_lifetime},
        value => 28,
    ),
    q{Defined ssl_server_certificate_lifetime parameter}
);

ok(
    EFS::CLI::Parameter->define(
        name  => q{install_audits_required},
        value => q{dependencies,forbidden_files},
    ),
    q{Defined install_audits_required parameter}
);

# Region, Campus, Location

ok(
    EFS::CLI::Region->define(
        name        => $config->get_value( q{Global}, q{region} ),
        description => q{Test region},
    ),
    q{Defined region}
);

ok(
    EFS::CLI::Campus->define(
        region      => $config->get_value( q{Global}, q{region} ),
        name        => $config->get_value( q{Global}, q{campus} ),
        description => q{Test campus},
    ),
    q{Defined campus}
);

ok(
    EFS::CLI::Location->define(
        region      => $config->get_value( q{Global}, q{region} ),
        campus      => $config->get_value( q{Global}, q{campus} ),
        name        => $config->get_value( q{Global}, q{location} ),
        description => q{Test location},
    ),
    q{Defined location}
);

# LocalDevCell

my $fstype  =$config->get_value( q{Filesystem}, q{type} );

ok(
    EFS::CLI::Cell->define(
        region   => $config->get_value( q{Global},       q{region} ),
        campus   => $config->get_value( q{Global},       q{campus} ),
        location => $config->get_value( q{Global},       q{location} ),
        name     => $config->get_value( q{LocalDevCell}, q{name} ),
        celltype => q{dev},
        fstype   => $fstype,
    ),
    q{Defined LocalDevCell}
);

ok(
    EFS::CLI::Fileserver->define(
        cell => $config->get_value( q{LocalDevCell}, q{name} ),
        name => $config->get_value( q{LocalDevCell}, q{fileserver} ),
    ),
    q{Defined LocalDevCell fileserver}
);

if ( $fstype eq q{afs} ) {

    foreach my $vicep ( split( m{\s+}msx, $config->get_value( q{LocalDevCell}, q{afsshares} ) ) ) {
        ok(
            EFS::CLI::Fileshare->define(
                cell       => $config->get_value( q{LocalDevCell}, q{name} ),
                fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
                name       => $vicep,
            ),
            qq{Defined LocalDevCell afsshare $vicep}
        );
    }

} else {

    ok(
        EFS::CLI::Fileshare->define(
            cell       => $config->get_value( q{LocalDevCell}, q{name} ),
            fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
            name       => $config->get_value( q{LocalDevCell}, q{devshare} ),
            filetype   => q{dev},
        ),
        q{Defined LocalDevCell devshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{LocalDevCell}, q{name} ),
            fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{LocalDevCell}, q{devshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined LocalDevCell devshare qtree}
    );

    ok( EFS::CLI::Fileshare->define(
        cell       => $config->get_value( q{LocalDevCell}, q{name} ),
        fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
        name       => $config->get_value( q{LocalDevCell}, q{homeshare} ),
        filetype   => q{home},
    ),
        q{Defined LocalDevCell homeshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{LocalDevCell}, q{name} ),
            fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{LocalDevCell}, q{homeshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined LocalDevCell homeshare qtree}
    );

    ok(
        EFS::CLI::Fileshare->define(
            cell       => $config->get_value( q{LocalDevCell}, q{name} ),
            fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
            name       => $config->get_value( q{LocalDevCell}, q{distshare} ),
            filetype   => q{dist},
        ),
        q{Defined LocalDevCell distshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{LocalDevCell}, q{name} ),
            fileserver => $config->get_value( q{LocalDevCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{LocalDevCell}, q{distshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined LocalDevCell distshare qtree}
    );

}

ok(
    EFS::CLI::Cell->expose(
        name => $config->get_value( q{LocalDevCell}, q{name} ),
    ),
    q{Exposed LocalDevCell},
);

# RemoteDevCell

ok(
    EFS::CLI::Cell->define(
        region   => $config->get_value( q{Global},        q{region} ),
        campus   => $config->get_value( q{Global},        q{campus} ),
        location => $config->get_value( q{Global},        q{location} ),
        name     => $config->get_value( q{RemoteDevCell}, q{name} ),
        celltype => q{dev},
        fstype   => $fstype,
    ),
    q{Defined RemoteDevCell}
);

ok(
    EFS::CLI::Fileserver->define(
        cell => $config->get_value( q{RemoteDevCell}, q{name} ),
        name => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
    ),
    q{Defined RemoteDevCell fileserver}
);

if ( $fstype eq q{afs} ) {

    foreach my $vicep ( split( m{\s+}msx, $config->get_value( q{RemoteDevCell}, q{afsshares} ) ) ) {
        ok(
            EFS::CLI::Fileshare->define(
                cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
                fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
                name       => $vicep,
            ),
            qq{Defined RemoteDevCell afsshare $vicep}
        );
    }    

} else {

    ok(
        EFS::CLI::Fileshare->define(
            cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
            fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
            name       => $config->get_value( q{RemoteDevCell}, q{devshare} ),
            filetype   => q{dev},
        ),
        q{Defined RemoteDevCell devshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
            fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{RemoteDevCell}, q{devshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined RemoteDevCell devshare qtree}
    );

    ok(
        EFS::CLI::Fileshare->define(
            cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
            fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
            name       => $config->get_value( q{RemoteDevCell}, q{homeshare} ),
            filetype   => q{home},
        ),
        q{Defined RemoteDevCell homeshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
            fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{RemoteDevCell}, q{homeshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined RemoteDevCell homeshare qtree}
    );

    ok(
        EFS::CLI::Fileshare->define(
            cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
            fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
            name       => $config->get_value( q{RemoteDevCell}, q{distshare} ),
            filetype   => q{dist},
        ),
        q{Defined RemoteDevCell distshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{RemoteDevCell}, q{name} ),
            fileserver => $config->get_value( q{RemoteDevCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{RemoteDevCell}, q{distshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined RemoteDevCell distshare qtree}
    );

}

ok(
    EFS::CLI::Cell->expose(
        name => $config->get_value( q{RemoteDevCell}, q{name} ),
    ),
    q{Exposed RemoteDevCell},
);

# LocalProdCell

ok(
    EFS::CLI::Cell->define(
        region     => $config->get_value( q{Global},        q{region} ),
        campus     => $config->get_value( q{Global},        q{campus} ),
        location   => $config->get_value( q{Global},        q{location} ),
        name       => $config->get_value( q{LocalProdCell}, q{name} ),
        celltype   => q{prod},
        fstype     => $fstype,
        parentcell => $config->get_value( q{LocalDevCell},  q{name} ),
    ),
    q{Defined LocalProdCell}
);

ok(
    EFS::CLI::Fileserver->define(
        cell => $config->get_value( q{LocalProdCell}, q{name} ),
        name => $config->get_value( q{LocalProdCell}, q{fileserver} ),
    ),
    q{Defined LocalProdCell fileserver}
);

if ( $fstype eq q{afs} ) {

    foreach my $vicep ( split( m{\s+}msx, $config->get_value( q{LocalProdCell}, q{afsshares} ) ) ) {
        ok(
            EFS::CLI::Fileshare->define(
                cell       => $config->get_value( q{LocalProdCell}, q{name} ),
                fileserver => $config->get_value( q{LocalProdCell}, q{fileserver} ),
                name       => $vicep
            ),
            qq{Defined LocalProdCell afsshare $vicep}
        );
    }

} else {

    ok(
        EFS::CLI::Fileshare->define(
            cell       => $config->get_value( q{LocalProdCell}, q{name} ),
            fileserver => $config->get_value( q{LocalProdCell}, q{fileserver} ),
            name       => $config->get_value( q{LocalProdCell}, q{distshare} ),
            filetype   => q{dist},
        ),
        q{Defined LocalProdCell distshare}
    );

    ok(
        EFS::CLI::Fileqtree->define(
            cell       => $config->get_value( q{LocalProdCell}, q{name} ),
            fileserver => $config->get_value( q{LocalProdCell}, q{fileserver} ),
            fileshare  => $config->get_value( q{LocalProdCell}, q{distshare} ),
            name       => q{efs_qtree},
        ),
        q{Defined LocalProdCell distshare qtree}
    );

}

ok(
    EFS::CLI::Cell->expose(
        name => $config->get_value( q{LocalProdCell}, q{name} ),
    ),
    q{Exposed LocalProdCell},
);

# EFSServers

ok(
    EFS::CLI::EFSServer->define(
        name     => $config->get_value( q{LocalDevCell}, q{efsserver} ),
        hosttype => q{test},
    ),
    q{Defined Local EFSServer}
);

ok(
    EFS::CLI::EFSServer->define(
        name     => $config->get_value( q{RemoteDevCell}, q{efsserver} ),
        hosttype => q{test},
    ),
    q{Defined Remote EFSServer}
);

ok(
    EFS::CLI::EFSServerCell->define(
        efsserver => $config->get_value( q{LocalDevCell}, q{efsserver} ),
        cell      => $config->get_value( q{LocalDevCell}, q{name} ),
    ),
    q{Defined EFSServer for LocalDevCell}
);

ok(
    EFS::CLI::EFSServerCell->define(
        efsserver => $config->get_value( q{LocalProdCell}, q{efsserver} ),
        cell      => $config->get_value( q{LocalProdCell}, q{name} ),
    ),
    q{Defined EFSServer for LocalProdCell}
);

ok(
    EFS::CLI::EFSServerCell->define(
        efsserver => $config->get_value( q{RemoteDevCell}, q{efsserver} ),
        cell      => $config->get_value( q{RemoteDevCell}, q{name} ),
    ),
    q{Defined EFSServer for RemoteDevCell}
);

# SSLServer(s)

ok(
    EFS::CLI::SSLServer->define(
        type      => q{primary},
        efsserver => $config->get_value( q{LocalProdCell}, q{efsserver} ),
    ),
    q{Defined LocalDevCell EFSServer as the primary SSLServer},
);

1;

__END__

=for :stopwords config

=head1 NOTES

This script will initialize the test environment database objects.

=head2 Initialize the database definitions for the test environment

This step will define all the objects based on the definitions in the
test suite config files.  The region, campus, location, cells, etc.

=cut
