#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 17;

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new;

my $release = q{testmeta/testproj/nolock};

my @setup = (
    q{efs display metaproj testmeta},
    q{efs display project testmeta testproj},
    q{efs create release testmeta testproj nolock},
    q{efs create install testmeta testproj nolock common},
    qq{touch /efs/dev/$release/install/common/foo},
);

foreach my $setup (@setup) {
    $test->efs_test_command(
        name    => qq{(setup) $setup},
        command => $setup,
        bail    => 1,
    );
}

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs display feature allow_insecure_disable_lockdown},
    expect  => q{No such feature 'allow_insecure_disable_lockdown'},,
    not     => 1,
    bail    => 1,
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs define feature allow_insecure_disable_lockdown 1},
    expect  => q{Defined feature 'allow_insecure_disable_lockdown'},,
);

$test->efs_test_command(
    command => q{efs setattr release testmeta testproj nolock disable_lockdown 1},
);

$test->efs_test_command(
    command => q{efs lock release testmeta testproj nolock},
    not     => 1,
    expect  => [
        qq{Release '$release' has the attribute 'disable_lockdown',},
        q{and can't be locked, explicitly or implicitly.},
    ],
);

$test->efs_test_command(
    command => q{efs checkpoint release testmeta testproj nolock},
    expect  => [
        qq{Performing dependencies audit on install $release/common},
        qq{Performing forbidden_files audit on install $release/common},
        qq{Updated initial checktime for install '$release/common'},
        qq{Successfully completed checkpoint for '$release'},
    ],
);

$test->efs_test_command(
    command => q{efs dist release testmeta testproj nolock},
);

$test->efs_test_command(
    command => q{efs setstage release testmeta testproj nolock prod},
    expect  => [
        qq{Validating the checkpoint state for release '$release'.},
        qq{Validating the audit state for release '$release'.},
        qq{Setting the unlocked release $release stage to prod,},
        q{since the allow_insecure_disable_lockdown feature is enabled.},
        qq{Changed the stage of $release from dev to prod},
    ],
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs undef feature allow_insecure_disable_lockdown},
    expect  => q{Undefined feature 'allow_insecure_disable_lockdown'},
);

$test->efs_test_command(
    command => q{efs history feature allow_insecure_disable_lockdown -count 2},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}xms,
        qr{-+}xms,
        qr{define \s+ feature \s+ allow_insecure_disable_lockdown}xms,
        qr{undef \s+ feature \s+ allow_insecure_disable_lockdown}xms,
    ],
);

my @teardown = (
    q{efs setstage release testmeta testproj nolock deprecated},
    q{efs destroy release testmeta testproj nolock },
    q{efs purge release testmeta testproj nolock -now},
);

foreach my $teardown ( @teardown ) {
    $test->efs_test_command(
        run_as  => q{efsops},
        name    => qq{(teardown) $teardown},
        command => $teardown,
    );
}

exit 0;

