#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 3;

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );
my $config = $test->get_config;

my $ldc_name = $config->get_value( q{LocalDevCell}, q{name} );
my $rdc_name = $config->get_value( q{RemoteDevCell}, q{name} );
my $lpc_name = $config->get_value( q{LocalProdCell}, q{name} );

$test->efs_test_command(
    command   => q{efs destroy project testmeta testproj},
    # Too many to count....
    filternot => qr{Removed \s+ directory \s+ \S+:/\.efs/}msx,
    expect    => [
        qr{directory \s+ $lpc_name./efs/dist/testmeta/testproj}msx,
        qr{directory \s+ $ldc_name./efs/dist/testmeta/testproj}msx,
        qr{directory \s+ $rdc_name./efs/dist/testmeta/testproj}msx,
        qr{directory \s+ $ldc_name./efs/dev/testmeta/testproj}msx,
        qq{Removed symlink $ldc_name:/efs/dev/testmeta/testproj},
        qq{Removed symlink $rdc_name:/efs/dev/testmeta/testproj},
        q{Destroyed project testmeta/testproj},
    ],
);

$test->efs_test_command(
    command => q{efs undef metaproj testmeta},
    not     => 1,
    expect  => [
        q{'efs undef metaproj' has been deprecated},
        q{Use 'efs destroy metaproj' instead},
    ],
);

$test->efs_test_command(
    command   => q{efs destroy metaproj testmeta},
    # Too many to count....
    filternot => qr{Removed \s+ directory \s+ \S+:/\.efs/}msx,
    expect    => [
        qr{directory \s+ $lpc_name./efs/dist/testmeta}msx,
        qr{directory \s+ $ldc_name./efs/dist/testmeta}msx,
        qr{directory \s+ $rdc_name./efs/dist/testmeta}msx,
        qr{directory \s+ $ldc_name./efs/dev/testmeta}msx,
        qr{directory \s+ $rdc_name./efs/dev/testmeta}msx,
        q{Destroyed metaproj testmeta},
    ],
);
