#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $business = q{testbusiness};
my $division = q{testdivision};

my $ssenisub = reverse $business;

$test->efs_test_command(
    command => qq{efs define business $business 'test business'}
);

$test->efs_test_command(
    name    => q{Verifying that the division doesn't exist...},
    command => qq{efs display division $business $division},
    not     => 1,
    expect  => [ qq{No such division '$division' in business '$business'}, ],
    bail    => 1,
);

$test->efs_test_command(
    name    => q{Define a bogus division},
    command => qq{efs define division $business UPPERCASE 'test division'},
    expect  => [
        q{Invalid division 'UPPERCASE'},
        q{Must consist solely of lower case letters (a-z)},
        q{Exit status from efs server not received.  Assuming failure...},
    ],
    not => 1,
);

$test->efs_test_command(
    name    => qq{Defined the division '$division'},
    command => qq{efs define division $business $division 'temp division'},
    expect  => [ qq{Defined division $division in business $business}, ],
);

$test->efs_test_command(
    name    => qq{Defined the division '$division' again},
    command => qq{efs define division $business $division 'test division'},
    expect  => [
        qq{Division $division in business $business is already defined},
        qq{Updated description of division $division},
    ],
);

$test->efs_test_command(
    name    => q{Define the other business},
    command => qq{efs define business $ssenisub 'other test business'},
);

$test->efs_test_command(
    name    => q{Try to define the division in the other business},
    command => qq{efs define division $ssenisub $division foo},
    not     => 1,
    expect  => [
        qq{Division $division is already defined, but in business $business},
    ],
);

$test->efs_test_command(
    name    => q{Set an attribute for the division},
    command => ( qq{efs setattr division $business $division foo bar}, ),
    expect  => [
        qq{For division '$division', defined attribute as:},
        q{'foo' => 'bar'},
    ],
);

$test->efs_test_command(
    command => qq{efs display business $business},
    expect  => [
        qr{Business \s+ Description}msx,
        qr{=+}msx,
        qr{$business \s+ test \s+ business}msx,
        qr{Business \s+ Division \s+ Description}msx,
        qr{=+}msx,
        qr{$business \s+ $division \s+ test \s+ division}msx,
    ],
);

$test->efs_test_command(
    command => qq{efs display division $business $division},
    expect  => [
        qr{Business \s+ Division \s+ Description}msx,
        qr{=+}msx,
        qr{$business \s+ $division \s+test \s+ division}msx,
        qr{Business \s+ Division \s+ Attribute \s+ Value}msx,
        qr{=+}msx,
        qr{$business \s+ $division \s+ foo \s+ bar}msx,
    ],
);

$test->efs_test_command(
    name    => q{Try to undef the business prematurely},
    command => qq{efs undef business $business},
    not     => 1,
    expect  => [
        qq{Unable to undef business $business, }
            . q{as it has the following divisions defined:},
        qq{$division},
    ],
);

$test->efs_test_command( command => qq{efs undef division $business $division} );

$test->efs_test_command( command => qq{efs undef business $business} );

$test->efs_test_command( command => qq{efs undef business $ssenisub} );

$test->efs_test_command(
    name    => q{Check the history entries},
    command => qq{efs history division $business $division -count 4},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ division \s+ $business \s+ $division}msx,
        qr{define \s+ division \s+ $business \s+ $division}msx,
        qr{setattr \s+ division \s+ $business \s+ $division}msx,
        qr{undef \s+ division \s+ $business \s+ $division}msx,
    ],
);


